@@ -262,7 +262,10 @@ class Handler(tornado.web.RequestHandler):
         self.write("<tr><th>Status</th><th>Commit</th><th>Author</th><th>Completed</th><th>Duration</th></tr>")
         for push in self.application.db.all("SELECT * FROM push ORDER BY created DESC LIMIT 25"):
             started = datetime.datetime.strptime(push["started"], "%Y-%m-%d %H:%M:%S")
-            completed = datetime.datetime.strptime(push["completed"], "%Y-%m-%d %H:%M:%S")
+            if push["completed"]:
+                completed = datetime.datetime.strptime(push["completed"], "%Y-%m-%d %H:%M:%S")
+            else:
+                completed = None
 
             self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>" %
                        (push["status"], push["commit"], push["author"],
